//
//  ImageViewSdFactory.m
//  image_sd
//
//  Created by Tim Duncan on 2021/1/15.
//

#import "ImageViewSdFactory.h"
#import "MJExtension.h"
#import "UnifiedAssets.h"
#import "ImageSdModels.h"
#import "UIImageView+WebCache.h"


@implementation ImageViewSdFactory

- (NSObject <FlutterMessageCodec> *)createArgsCodec {
  return [FlutterStandardMessageCodec sharedInstance];
}

- (NSObject <FlutterPlatformView> *)createWithFrame:(CGRect)frame
                                     viewIdentifier:(int64_t)viewId
                                          arguments:(id _Nullable)args {
    UnifiedImageSdOptions *options = [UnifiedImageSdOptions mj_objectWithKeyValues:(NSString *) args];

    ImageSdView *view = [[ImageSdView alloc] initWithFrame:frame
                                           options:options
                                    viewIdentifier:viewId];
  return view;
}


@end

@implementation ImageSdView {
  CGRect _frame;
  int64_t _viewId;
  UnifiedImageSdOptions *_options;
  UIImageView *_imageSdV;
}

- (instancetype)initWithFrame:(CGRect)frame
                      options:(UnifiedImageSdOptions *)options
               viewIdentifier:(int64_t)viewId {
   
  if (self = [super init]) {
    _frame = frame;
    _viewId = viewId;
    _options = options;

    _imageSdV = [[UIImageView alloc] initWithFrame:_frame];
    _imageSdV.contentMode = UIViewContentModeScaleAspectFill;
    _imageSdV.clipsToBounds = YES;
    [self setup];
  }
  return self;
}

- (UIView *)view {
  return _imageSdV;
}

- (void)setup {
    _imageSdV.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    [_imageSdV sd_setImageWithURL:[NSURL URLWithString:_options.url] placeholderImage:[UIImage imageWithContentsOfFile:[UnifiedAssets getAssetPath:_options.icon]]];
}

@end


